@@ -1,7 +1,9 @@
 ## ----set-options, echo = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>", dev = "png", fig.width = 7, fig.height = 4, message = FALSE, warning = FALSE)
 options(width = 800)
-if (!requireNamespace("ggplot2", quietly = TRUE) ||
+dev_version <- length(strsplit(packageDescription("ggeffects")$Version, "\\.")[[1]]) > 3
+if (!dev_version ||
+    !requireNamespace("ggplot2", quietly = TRUE) ||
     !requireNamespace("lme4", quietly = TRUE) ||
     !requireNamespace("glmmTMB", quietly = TRUE) ||
     !requireNamespace("sjlabelled", quietly = TRUE)) {
@@ -9,84 +11,87 @@ if (!requireNamespace("ggplot2", quietly = TRUE) ||
 }
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-library(ggeffects)
-library(lme4)
-data(sleepstudy)
-m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
-
-pr <- ggpredict(m, "Days")
-pr
-plot(pr)
+#  library(ggeffects)
+#  library(lme4)
+#  data(sleepstudy)
+#  m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
+#  
+#  pr <- ggpredict(m, "Days")
+#  pr
+#  plot(pr)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-pr <- ggpredict(m, "Days", type = "random")
-pr
-plot(pr)
+#  pr <- ggpredict(m, "Days", type = "random")
+#  pr
+#  plot(pr)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "Days", type = "random", condition = c(Subject = 330))
+#  ggpredict(m, "Days", type = "random", condition = c(Subject = 330))
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "Days", type = "sim")
+#  ggpredict(m, "Days", type = "sim")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-library(glmmTMB)
-data(Salamanders)
-m <- glmmTMB(
-  count ~ spp + mined + (1 | site), 
-  ziformula = ~ spp + mined, 
-  family = truncated_poisson, 
-  data = Salamanders
-)
+#  library(glmmTMB)
+#  data(Salamanders)
+#  m <- glmmTMB(
+#    count ~ spp + mined + (1 | site),
+#    ziformula = ~ spp + mined,
+#    family = truncated_poisson,
+#    data = Salamanders
+#  )
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "spp")
-
-ggpredict(m, "spp", type = "random")
+#  ggpredict(m, "spp")
+#  
+#  ggpredict(m, "spp", type = "random")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "spp", type = "zero_inflated")
+#  ggpredict(m, "spp", type = "zero_inflated")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "spp", type = "zi_random")
+#  ggpredict(m, "spp", type = "zi_random")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ggpredict(m, "spp", type = "sim")
+#  ggpredict(m, "spp", type = "simulate")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-library(sjlabelled)
-data(efc)
-efc$e15relat <- as_label(efc$e15relat)
-m <- lmer(neg_c_7 ~ c12hour + c160age + c161sex + (1 | e15relat), data = efc)
-me <- ggpredict(m, terms = "c12hour")
-plot(me)
+#  library(sjlabelled)
+#  data(efc)
+#  efc$e15relat <- as_label(efc$e15relat)
+#  m <- lmer(neg_c_7 ~ c12hour + c160age + c161sex + (1 | e15relat), data = efc)
+#  me <- ggpredict(m, terms = "c12hour")
+#  plot(me)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-me <- ggpredict(m, terms = "c12hour", type = "random")
-plot(me)
+#  me <- ggpredict(m, terms = "c12hour", type = "random")
+#  plot(me)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-me <- ggpredict(m, terms = c("c12hour", "e15relat"), type = "random")
-plot(me)
+#  me <- ggpredict(m, terms = c("c12hour", "e15relat"), type = "random")
+#  plot(me, ci = FALSE)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-me <- ggpredict(m, terms = c("c12hour", "e15relat [child,sibling]"), type = "random")
-plot(me)
+#  me <- ggpredict(m, terms = c("c12hour", "e15relat [child,sibling]"), type = "random")
+#  plot(me, ci = FALSE)
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  plot(me)
 
 ## ----fig.height=6-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-me <- ggpredict(
-  m, 
-  terms = c("c12hour", "c161sex", "c160age", "e15relat [child,sibling]"), 
-  type = "random"
-)
-plot(me)
+#  me <- ggpredict(
+#    m,
+#    terms = c("c12hour", "c161sex", "c160age", "e15relat [child,sibling]"),
+#    type = "random"
+#  )
+#  plot(me)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-set.seed(123)
-m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
-me <- ggpredict(m, terms = c("Days", "Subject [sample=7]"), type = "random")
-plot(me)
+#  set.seed(123)
+#  m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
+#  me <- ggpredict(m, terms = c("Days", "Subject [sample=7]"), type = "random")
+#  plot(me)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-plot(me, add.data = TRUE)
+#  plot(me, add.data = TRUE, ci = FALSE)
 
